@@ -18,6 +18,8 @@ class App():
     def run(self):
         """Game loop."""
 
+        self.renderer.render(self.game.match)
+
         while self.is_app_running:
             input_registered, key = self.input.wait_for_user_input()
 
@@ -37,8 +39,9 @@ class App():
 
 
 def main():
-    app = App()
-    app.run()
+    app = App()  # pragma: no cover
+    app.run()  # pragma: no cover
+
 
 if __name__ == "__main__":
-    main()    
\ No newline at end of file
+    main()  # pragma: no cover
