@@ -16,10 +16,6 @@ class Game():
         elif self._is_match_ongoing():
             self._process_input_match(input)
 
-    def get_game_board(self):
-        """Return game board as list of Column objects"""
-        return self.match.board.columns
-
     def _reset_match(self):
         """Create a new match in default state."""
         self.match = Match()
